@@ -18,6 +18,7 @@
 #include <QVariant>
 
 #include "fetcher.h"
+#include "models/errorlogmodel.h"
 
 PodcastSearchModel::PodcastSearchModel(QObject *parent)
     : QAbstractListModel(parent)
@@ -138,7 +139,7 @@ void PodcastSearchModel::search(const QString &text)
     QNetworkRequest request(QUrl(QStringLiteral("https://api.podcastindex.org/api/1.0/search/byterm?q=%1").arg(text)));
     QString url = QStringLiteral("https://api.podcastindex.org/api/1.0/search/byterm?q=%1").arg(text);
     request.setRawHeader("X-Auth-Key", "BLVCJJSWUJGD3WJQSZ56");
-    auto time = QDateTime::currentDateTime().toSecsSinceEpoch();
+    auto time = QDateTime::currentSecsSinceEpoch();
     request.setRawHeader("X-Auth-Date", QString::number(time).toLatin1());
     QString hashString = QStringLiteral(
                              "BLVCJJSWUJGD3WJQSZ56"
@@ -147,7 +148,7 @@ void PodcastSearchModel::search(const QString &text)
     auto hash = QCryptographicHash::hash(hashString.toLatin1(), QCryptographicHash::Sha1);
     request.setRawHeader("Authorization", hash.toHex());
     auto reply = Fetcher::instance().get(request);
-    connect(reply, &QNetworkReply::finished, this, [=]() {
+    connect(reply, &QNetworkReply::finished, this, [this, reply, url]() {
         if (reply->error()) {
             ErrorLogModel::instance().monitorErrorMessages(Error::Type::DiscoverError, url, QString(), reply->error(), reply->errorString(), url);
         } else {
