@@ -26,22 +26,18 @@
 #include "database.h"
 #include "datamanager.h"
 #include "entry.h"
-#include "fetcher.h"
 #include "models/errorlogmodel.h"
 #include "settingsmanager.h"
 #include "sync/gpodder/devicerequest.h"
-#include "sync/gpodder/episodeactionrequest.h"
 #include "sync/gpodder/gpodder.h"
 #include "sync/gpodder/logoutrequest.h"
 #include "sync/gpodder/subscriptionrequest.h"
 #include "sync/gpodder/syncrequest.h"
 #include "sync/gpodder/updatedevicerequest.h"
 #include "sync/gpodder/updatesyncrequest.h"
-#include "sync/gpodder/uploadepisodeactionrequest.h"
 #include "sync/gpodder/uploadsubscriptionrequest.h"
 #include "sync/syncjob.h"
 #include "sync/syncutils.h"
-#include "utils/fetchfeedsjob.h"
 #include "utils/networkconnectionmanager.h"
 #include "utils/storagemanager.h"
 
@@ -66,7 +62,7 @@ void Sync::retrieveCredentialsFromConfig()
         m_hostname = SettingsManager::self()->syncHostname();
         m_provider = static_cast<Provider>(SettingsManager::self()->syncProvider());
 
-        connect(this, &Sync::passwordRetrievalFinished, this, [=](QString password) {
+        connect(this, &Sync::passwordRetrievalFinished, this, [this](QString password) {
             disconnect(this, &Sync::passwordRetrievalFinished, this, nullptr);
             if (!password.isEmpty()) {
                 m_syncEnabled = SettingsManager::self()->syncEnabled();
@@ -213,7 +209,7 @@ void Sync::setPassword(const QString &password)
 {
     // this method is used to set the password if the proper credentials could
     // not be retrieved from the keychain or file
-    connect(this, &Sync::passwordSaveFinished, this, [=]() {
+    connect(this, &Sync::passwordSaveFinished, this, [this]() {
         disconnect(this, &Sync::passwordSaveFinished, this, nullptr);
         QTimer::singleShot(0, this, [this]() {
             retrieveCredentialsFromConfig();
@@ -250,7 +246,7 @@ void Sync::setHostname(const QString &hostname)
             hostUrl.setScheme(QStringLiteral("https"));
             if (hostUrl.authority().isEmpty() && !hostUrl.path().isEmpty()) {
                 hostUrl.setAuthority(hostUrl.path());
-                hostUrl.setPath(QStringLiteral(""));
+                hostUrl.setPath(QLatin1String(""));
             }
             cleanedHostname = hostUrl.toString();
         }
@@ -283,13 +279,13 @@ void Sync::login(const QString &username, const QString &password)
     if (m_provider == Provider::GPodderNextcloud) {
         m_gpodder = new GPodder(username, password, m_hostname, Provider::GPodderNextcloud, this);
 
-        SubscriptionRequest *subRequest = m_gpodder->getSubscriptionChanges(0, QStringLiteral(""));
-        connect(subRequest, &SubscriptionRequest::finished, this, [=]() {
+        SubscriptionRequest *subRequest = m_gpodder->getSubscriptionChanges(0, QLatin1String(""));
+        connect(subRequest, &SubscriptionRequest::finished, this, [this, subRequest, username, password]() {
             if (subRequest->error() || subRequest->aborted()) {
                 if (subRequest->error()) {
                     Q_EMIT error(Error::Type::SyncError,
-                                 QStringLiteral(""),
-                                 QStringLiteral(""),
+                                 QLatin1String(""),
+                                 QLatin1String(""),
                                  subRequest->error(),
                                  subRequest->errorString(),
                                  i18n("Could not log into GPodder-nextcloud server"));
@@ -298,7 +294,7 @@ void Sync::login(const QString &username, const QString &password)
                     setSyncEnabled(false);
                 }
             } else {
-                connect(this, &Sync::passwordSaveFinished, this, [=](bool success) {
+                connect(this, &Sync::passwordSaveFinished, this, [this, username, password](bool success) {
                     disconnect(this, &Sync::passwordSaveFinished, this, nullptr);
                     if (success) {
                         m_username = username;
@@ -323,12 +319,12 @@ void Sync::login(const QString &username, const QString &password)
         }
 
         DeviceRequest *deviceRequest = m_gpodder->getDevices();
-        connect(deviceRequest, &DeviceRequest::finished, this, [=]() {
+        connect(deviceRequest, &DeviceRequest::finished, this, [this, deviceRequest, username, password]() {
             if (deviceRequest->error() || deviceRequest->aborted()) {
                 if (deviceRequest->error()) {
                     Q_EMIT error(Error::Type::SyncError,
-                                 QStringLiteral(""),
-                                 QStringLiteral(""),
+                                 QLatin1String(""),
+                                 QLatin1String(""),
                                  deviceRequest->error(),
                                  deviceRequest->errorString(),
                                  i18n("Could not log into GPodder server"));
@@ -341,7 +337,7 @@ void Sync::login(const QString &username, const QString &password)
             } else {
                 m_deviceList = deviceRequest->devices();
 
-                connect(this, &Sync::passwordSaveFinished, this, [=](bool success) {
+                connect(this, &Sync::passwordSaveFinished, this, [this, username, password](bool success) {
                     disconnect(this, &Sync::passwordSaveFinished, this, nullptr);
                     if (success) {
                         m_username = username;
@@ -371,7 +367,7 @@ void Sync::logout()
             return;
         }
         LogoutRequest *logoutRequest = m_gpodder->logout();
-        connect(logoutRequest, &LogoutRequest::finished, this, [=]() {
+        connect(logoutRequest, &LogoutRequest::finished, this, [this, logoutRequest]() {
             if (logoutRequest->error() || logoutRequest->aborted()) {
                 if (logoutRequest->error()) {
                     // Let's not report this error, since it doesn't matter anyway:
@@ -380,8 +376,8 @@ void Sync::logout()
                     //    shouldn't matter either, since the session probably expired
                     /*
                     Q_EMIT error(Error::Type::SyncError,
-                                QStringLiteral(""),
-                                QStringLiteral(""),
+                                QLatin1String(""),
+                                QLatin1String(""),
                                 logoutRequest->error(),
                                 logoutRequest->errorString(),
                                 i18n("Could not log out of GPodder server"));
@@ -479,7 +475,7 @@ void Sync::savePasswordToFile(const QString &username, const QString &password)
     if (!((fileDir.exists() || fileDir.mkpath(QStringLiteral("."))) && passwordFile.open(QFile::WriteOnly))) {
         Q_EMIT error(Error::Type::SyncError,
                      passwordFile.fileName(),
-                     QStringLiteral(""),
+                     QLatin1String(""),
                      0,
                      i18n("I/O denied: Cannot save password."),
                      i18n("I/O denied: Cannot save password."));
@@ -501,7 +497,7 @@ void Sync::retrievePasswordFromKeyChain(const QString &username)
     writeDummyJob->setKey(QStringLiteral("dummy"));
     writeDummyJob->setTextData(QStringLiteral("dummy"));
 
-    QKeychain::WritePasswordJob::connect(writeDummyJob, &QKeychain::Job::finished, this, [=]() {
+    QKeychain::WritePasswordJob::connect(writeDummyJob, &QKeychain::Job::finished, this, [this, writeDummyJob, username]() {
         if (writeDummyJob->error()) {
             qCDebug(kastsSync) << "Could not open keychain: " << qPrintable(writeDummyJob->errorString());
             // fall back to password from file
@@ -513,7 +509,7 @@ void Sync::retrievePasswordFromKeyChain(const QString &username)
             readJob->setAutoDelete(false);
             readJob->setKey(username);
 
-            connect(readJob, &QKeychain::Job::finished, this, [=]() {
+            connect(readJob, &QKeychain::Job::finished, this, [this, readJob, username]() {
                 if (readJob->error() == QKeychain::Error::NoError) {
                     Q_EMIT passwordRetrievalFinished(readJob->textData());
                     // if a password file is present, delete it
@@ -526,7 +522,7 @@ void Sync::retrievePasswordFromKeyChain(const QString &username)
                     if (readJob->error() == QKeychain::Error::EntryNotFound) {
                         if (!password.isEmpty()) {
                             qCDebug(kastsSync) << "Migrating password from file to the keychain for " << username;
-                            connect(this, &Sync::passwordSaveFinished, this, [=](bool saved) {
+                            connect(this, &Sync::passwordSaveFinished, this, [this, username](bool saved) {
                                 disconnect(this, &Sync::passwordSaveFinished, this, nullptr);
                                 bool removed = false;
                                 if (saved) {
@@ -560,12 +556,12 @@ QString Sync::retrievePasswordFromFile(const QString &username)
     } else {
         Q_EMIT error(Error::Type::SyncError,
                      passwordFile.fileName(),
-                     QStringLiteral(""),
+                     QLatin1String(""),
                      0,
                      i18n("I/O denied: Cannot access password file."),
                      i18n("I/O denied: Cannot access password file."));
 
-        return QStringLiteral("");
+        return QLatin1String("");
     }
 }
 
@@ -637,12 +633,12 @@ void Sync::registerNewDevice(const QString &id, const QString &caption, const QS
         return;
     }
     UpdateDeviceRequest *updateDeviceRequest = m_gpodder->updateDevice(id, caption, type);
-    connect(updateDeviceRequest, &UpdateDeviceRequest::finished, this, [=]() {
+    connect(updateDeviceRequest, &UpdateDeviceRequest::finished, this, [this, updateDeviceRequest, id, caption]() {
         if (updateDeviceRequest->error() || updateDeviceRequest->aborted()) {
             if (updateDeviceRequest->error()) {
                 Q_EMIT error(Error::Type::SyncError,
-                             QStringLiteral(""),
-                             QStringLiteral(""),
+                             QLatin1String(""),
+                             QLatin1String(""),
                              updateDeviceRequest->error(),
                              updateDeviceRequest->errorString(),
                              i18n("Could not create GPodder device"));
@@ -663,12 +659,12 @@ void Sync::linkUpAllDevices()
         return;
     }
     SyncRequest *syncRequest = m_gpodder->getSyncStatus();
-    connect(syncRequest, &SyncRequest::finished, this, [=]() {
+    connect(syncRequest, &SyncRequest::finished, this, [this, syncRequest]() {
         if (syncRequest->error() || syncRequest->aborted()) {
             if (syncRequest->error()) {
                 Q_EMIT error(Error::Type::SyncError,
-                             QStringLiteral(""),
-                             QStringLiteral(""),
+                             QLatin1String(""),
+                             QLatin1String(""),
                              syncRequest->error(),
                              syncRequest->errorString(),
                              i18n("Could not retrieve synced device status"));
@@ -677,27 +673,29 @@ void Sync::linkUpAllDevices()
             return;
         }
 
-        QSet<QString> syncDevices;
-        for (const QStringList &group : syncRequest->syncedDevices()) {
-            syncDevices += QSet(group.begin(), group.end());
+        QStringList syncDevices;
+        QVector<QStringList> rawSyncedDevices = syncRequest->syncedDevices();
+        for (const QStringList &group : std::as_const(rawSyncedDevices)) {
+            syncDevices += group;
         }
-        syncDevices += QSet(syncRequest->unsyncedDevices().begin(), syncRequest->unsyncedDevices().end());
+        syncDevices += syncRequest->unsyncedDevices();
 
+        syncDevices.removeDuplicates();
         QVector<QStringList> syncDeviceGroups;
-        syncDeviceGroups += QStringList(syncDevices.values());
+        syncDeviceGroups += syncDevices;
         if (!m_gpodder) {
             return;
         }
         UpdateSyncRequest *upSyncRequest = m_gpodder->updateSyncStatus(syncDeviceGroups, QStringList());
-        connect(upSyncRequest, &UpdateSyncRequest::finished, this, [=]() {
+        connect(upSyncRequest, &UpdateSyncRequest::finished, this, [this, upSyncRequest, syncDevices]() {
             // For some reason, the response is always "Internal Server Error"
             // even though the request is processed properly.  So we just
             // continue rather than abort...
             if (upSyncRequest->error() || upSyncRequest->aborted()) {
                 if (upSyncRequest->error()) {
                     // Q_EMIT error(Error::Type::SyncError,
-                    //            QStringLiteral(""),
-                    //            QStringLiteral(""),
+                    //            QLatin1String(""),
+                    //            QLatin1String(""),
                     //            upSyncRequest->error(),
                     //            upSyncRequest->errorString(),
                     //            i18n("Could not update synced device status"));
@@ -714,12 +712,12 @@ void Sync::linkUpAllDevices()
                     return;
                 }
                 SubscriptionRequest *subRequest = m_gpodder->getSubscriptionChanges(0, device);
-                connect(subRequest, &SubscriptionRequest::finished, this, [=]() {
+                connect(subRequest, &SubscriptionRequest::finished, this, [this, subRequest, device, syncDevices]() {
                     if (subRequest->error() || subRequest->aborted()) {
                         if (subRequest->error()) {
                             Q_EMIT error(Error::Type::SyncError,
-                                         QStringLiteral(""),
-                                         QStringLiteral(""),
+                                         QLatin1String(""),
+                                         QLatin1String(""),
                                          subRequest->error(),
                                          subRequest->errorString(),
                                          i18n("Could not retrieve subscriptions for device %1", device));
@@ -737,8 +735,8 @@ void Sync::linkUpAllDevices()
                             connect(upSubRequest, &UploadSubscriptionRequest::finished, this, [this, upSubRequest, syncdevice]() {
                                 if (upSubRequest->error()) {
                                     Q_EMIT error(Error::Type::SyncError,
-                                                 QStringLiteral(""),
-                                                 QStringLiteral(""),
+                                                 QLatin1String(""),
+                                                 QLatin1String(""),
                                                  upSubRequest->error(),
                                                  upSubRequest->errorString(),
                                                  i18n("Could not upload subscriptions for device %1", syncdevice));
@@ -772,7 +770,7 @@ void Sync::doSync(SyncStatus status, bool forceFetchAll)
 
     // If a quick upload-only sync is running, abort it
     if (m_syncStatus == SyncStatus::UploadOnlySync) {
-        abortSync();
+        Q_EMIT abortSync();
     }
 
     m_syncStatus = status;
@@ -791,7 +789,7 @@ void Sync::doSync(SyncStatus status, bool forceFetchAll)
     });
     connect(syncJob, &SyncJob::finished, this, [this](KJob *job) {
         if (job->error()) {
-            Q_EMIT error(Error::Type::SyncError, QStringLiteral(""), QStringLiteral(""), job->error(), job->errorText(), job->errorString());
+            Q_EMIT error(Error::Type::SyncError, QLatin1String(""), QLatin1String(""), job->error(), job->errorText(), job->errorString());
         }
         m_syncStatus = SyncStatus::NoSync;
         Q_EMIT syncProgressChanged();
